============
Contributors
============

Author

* `Lucas Shen Y. S <https://github.com/lsys>`_

Contributors

* `David Lesieur <https://github.com/davidlesieur>`_
* `Christophe Bedetti <https://github.com/cbedetti>`_
* `Garrett Hurst <https://github.com/g-hurst>`_
* `Sreetama2001 <https://github.com/Sreetama2001>`_
* `Earl Brown <https://github.com/Sreetama2001>`_

(See the `Contributors <https://github.com/LSYS/LexicalRichness/graphs/contributors>`_ page)
